@@ -1,8 +1,13 @@
+from typing import Any, Optional
 import numpy as np
 import scipy.optimize as sco
 
+from . import transform
 
-def inverse_kinematics(serial_chain, pose, initial_state=None):
+
+def inverse_kinematics(
+    serial_chain: Any, pose: transform.Transform, initial_state: Optional[np.ndarray] = None
+) -> np.ndarray:
     ndim = len(serial_chain.get_joint_parameter_names())
     if initial_state is None:
         x0 = np.zeros(ndim)
@@ -14,5 +19,5 @@ def inverse_kinematics(serial_chain, pose, initial_state=None):
         obj = np.square(np.linalg.lstsq(pose.matrix(), tf.matrix(), rcond=-1)[0] - np.identity(4)).sum()
         return obj
 
-    ret = sco.minimize(object_fn, x0, method='BFGS')
-    return ret.x
\ No newline at end of file
+    ret = sco.minimize(object_fn, x0, method="BFGS")
+    return ret.x
