@@ -1,36 +1,47 @@
+from typing import Dict, Optional
 from . import chain, frame, mjcf_parser, transform
 
-JOINT_TYPE_MAP = {'hinge': 'revolute'}
 
-def geoms_to_visuals(geom, base=transform.Transform()):
+JOINT_TYPE_MAP: Dict[str, str] = {"hinge": "revolute", "slide": "prismatic"}
+
+
+def geoms_to_visuals(geom, base: Optional[transform.Transform] = None):
+    base = base or transform.Transform()
     visuals = []
     for g in geom:
-        if g.type == 'capsule':
+        if g.type == "capsule":
             param = (g.size[0], g.fromto)
-        elif g.type == 'sphere':
+        elif g.type == "sphere":
             param = g.size[0]
         else:
-            raise ValueError('Invalid geometry type %s.' % g.type)
-        visuals.append(frame.Visual(offset=base * transform.Transform(g.quat, g.pos),
-                                    geom_type=g.type,
-                                    geom_param=param))
+            raise ValueError("Invalid geometry type %s." % g.type)
+        visuals.append(
+            frame.Visual(offset=base * transform.Transform(g.quat, g.pos), geom_type=g.type, geom_param=param)
+        )
     return visuals
 
 
-def body_to_link(body, base=transform.Transform()):
-    return frame.Link(body.name,
-                      offset=base * transform.Transform(body.quat, body.pos))
+def body_to_link(body, base: Optional[transform.Transform] = None):
+    base = base or transform.Transform()
+    return frame.Link(body.name, offset=base * transform.Transform(body.quat, body.pos))
 
-def joint_to_joint(joint, base=transform.Transform()):
-    return frame.Joint(joint.name,
-                       offset=base * transform.Transform(pos=joint.pos),
-                       joint_type=JOINT_TYPE_MAP[joint.type],
-                       axis=joint.axis)
 
-def add_composite_joint(root_frame, joints, base=transform.Transform()):
+def joint_to_joint(joint, base: Optional[transform.Transform] = None):
+    base = base or transform.Transform()
+    return frame.Joint(
+        joint.name,
+        offset=base * transform.Transform(pos=joint.pos),
+        joint_type=JOINT_TYPE_MAP[joint.type],
+        axis=joint.axis,
+    )
+
+
+def add_composite_joint(root_frame, joints, base: Optional[transform.Transform] = None):
+    base = base or transform.Transform()
     if len(joints) > 0:
-        root_frame.children = root_frame.children + [frame.Frame(link=frame.Link(name=root_frame.link.name + '_child'),
-                                                                 joint=joint_to_joint(joints[0], base))]
+        root_frame.children = root_frame.children + [
+            frame.Frame(link=frame.Link(name=root_frame.link.name + "_child"), joint=joint_to_joint(joints[0], base))
+        ]
         ret, offset = add_composite_joint(root_frame.children[-1], joints[1:])
         return ret, root_frame.joint.offset * offset
     else:
@@ -53,7 +64,7 @@ def _build_chain_recurse(root_frame, root_body):
         _build_chain_recurse(next_frame, b)
 
 
-def build_chain_from_mjcf(data):
+def build_chain_from_mjcf(data: str) -> chain.Chain:
     """
     Build a Chain object from MJCF data.
 
@@ -69,9 +80,7 @@ def build_chain_from_mjcf(data):
     """
     model = mjcf_parser.from_xml_string(data)
     root_body = model.worldbody.body[0]
-    root_frame = frame.Frame(root_body.name + "_frame",
-                             link=body_to_link(root_body),
-                             joint=frame.Joint())
+    root_frame = frame.Frame(root_body.name + "_frame", link=body_to_link(root_body), joint=frame.Joint())
     _build_chain_recurse(root_frame, root_body)
     return chain.Chain(root_frame)
 
@@ -95,5 +104,6 @@ def build_serial_chain_from_mjcf(data, end_link_name, root_link_name=""):
         SerialChain object created from MJCF.
     """
     mjcf_chain = build_chain_from_mjcf(data)
-    return chain.SerialChain(mjcf_chain, end_link_name + "_frame",
-                             "" if root_link_name == "" else root_link_name + "_frame")
+    return chain.SerialChain(
+        mjcf_chain, end_link_name + "_frame", "" if root_link_name == "" else root_link_name + "_frame"
+    )
